
# Slot: exact match


holds between two entities that have strictly equivalent meanings, with a high degree of confidence

URI: [biolink:exact_match](https://w3id.org/biolink/vocab/exact_match)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [close match](close_match.md)

## Children

 *  [same as](same_as.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | skos:exactMatch |
|  | | WIKIDATA:Q39893449 |
|  | | WIKIDATA:P2888 |

